Package: distionary
Title: Create and Evaluate Probability Distributions
Version: 0.1.1
Authors@R: c(
    person("Vincenzo", "Coia", , "vincenzo.coia@gmail.com", 
           role = c("aut", "cre", "cph")),
    person("Amogh", "Joshi", role = "ctb"),
    person("Shuyi", "Tan", role = "ctb"),
    person("Zhipeng", "Zhu", role = "ctb"),
    person("olivroy", role = "ctb", comment = "GitHub contributor"))
Description: Create and evaluate probability distribution objects from a
    variety of families or define custom distributions. Automatically compute
    distributional properties, even when they have not been specified.
    This package supports statistical modeling and simulations, and forms
    the core of the probaverse suite of R packages.
License: MIT + file LICENSE
Suggests: covr, knitr, rmarkdown, testthat (>= 3.0.0), tibble
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: checkmate, rlang, stats, vctrs
VignetteBuilder: knitr
URL: https://distionary.probaverse.com/,
        https://github.com/probaverse/distionary
BugReports: https://github.com/probaverse/distionary/issues
Depends: R (>= 2.10)
NeedsCompilation: no
Packaged: 2026-04-27 07:30:28 UTC; VCoia
Author: Vincenzo Coia [aut, cre, cph],
  Amogh Joshi [ctb],
  Shuyi Tan [ctb],
  Zhipeng Zhu [ctb],
  olivroy [ctb] (GitHub contributor)
Maintainer: Vincenzo Coia <vincenzo.coia@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-27 09:00:02 UTC
Built: R 4.6.0; ; 2026-04-27 09:52:18 UTC; unix
