# Generated by roxygen2: do not edit by hand

S3method(mean,dst)
S3method(median,dst)
S3method(plot,dst)
S3method(print,dst)
S3method(range,dst)
export("parameters<-")
export(dgev)
export(dgp)
export(distribution)
export(dst_bern)
export(dst_beta)
export(dst_binom)
export(dst_cauchy)
export(dst_chisq)
export(dst_degenerate)
export(dst_empirical)
export(dst_exp)
export(dst_f)
export(dst_finite)
export(dst_gamma)
export(dst_geom)
export(dst_gev)
export(dst_gp)
export(dst_hyper)
export(dst_lnorm)
export(dst_lp3)
export(dst_nbinom)
export(dst_norm)
export(dst_null)
export(dst_pearson3)
export(dst_pois)
export(dst_t)
export(dst_unif)
export(dst_weibull)
export(enframe_cdf)
export(enframe_chf)
export(enframe_density)
export(enframe_hazard)
export(enframe_odds)
export(enframe_pmf)
export(enframe_quantile)
export(enframe_return)
export(enframe_survival)
export(eval_cdf)
export(eval_chf)
export(eval_density)
export(eval_hazard)
export(eval_odds)
export(eval_pmf)
export(eval_property)
export(eval_quantile)
export(eval_return)
export(eval_survival)
export(is.distribution)
export(is_distribution)
export(kurtosis)
export(kurtosis_exc)
export(parameters)
export(pgev)
export(pgp)
export(pretty_name)
export(prob_left)
export(prob_right)
export(qgev)
export(qgp)
export(realise)
export(realize)
export(skewness)
export(stdev)
export(variance)
export(vtype)
importFrom(stats,median)
