% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dst_exp.R
\name{dst_exp}
\alias{dst_exp}
\title{Exponential Distribution}
\usage{
dst_exp(rate)
}
\arguments{
\item{rate}{Rate parameter; single positive numeric.}
}
\value{
An Exponential distribution.
}
\description{
Makes an Exponential distribution.
}
\examples{
dst_exp(1)
}
