% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dst_lnorm.R
\name{dst_lnorm}
\alias{dst_lnorm}
\title{Log Normal Distribution}
\usage{
dst_lnorm(meanlog, sdlog)
}
\arguments{
\item{meanlog}{Mean of the log of the random variable;
single numeric.}

\item{sdlog}{Standard deviation of the log of the random variable;
single positive numeric.}
}
\value{
A Log Normal distribution.
}
\description{
Makes a Log Normal distribution, which is the distribution of
the exponential of a Normally distributed random variable.
}
\examples{
dst_lnorm(0, 1)
}
