% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dst_norm.R
\name{dst_norm}
\alias{dst_norm}
\title{Normal (Gaussian) Distribution}
\usage{
dst_norm(mean, sd)
}
\arguments{
\item{mean}{Mean of the distribution. Single numeric.}

\item{sd}{Standard deviation of the distribution.
Single positive numeric.}
}
\value{
A Normal distribution.
}
\description{
Makes a Normal (Gaussian) distribution.
}
\examples{
dst_norm(0, 1)
}
