% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/realise.R
\name{realise}
\alias{realise}
\alias{realize}
\title{Generate a Sample from a Distribution}
\usage{
realise(distribution, n = 1)

realize(distribution, n = 1)
}
\arguments{
\item{distribution}{Distribution object.}

\item{n}{Number of observations to generate.}
}
\value{
Vector of independent values drawn from the inputted distribution.
}
\description{
Draw \code{n} independent observations from a distribution.
}
\note{
\code{realise()} and \code{realize()} are aliases and do the same thing.
}
\examples{
d <- dst_pois(5)
set.seed(2)
realise(d, n = 10)
}
